Structs
Functions
- get_
networks - Get network information by reading the
/proc/net/devfile. - get_
networks_ with_ speed - Get network information by reading the
/proc/net/devfile and measure the speed within a specific time interval.
/proc/net/dev file./proc/net/dev file and measure the speed within a specific time interval.