pub struct ProcessStatus {
    pub real_uid: u32,
    pub real_gid: u32,
    pub effective_uid: u32,
    pub effective_gid: u32,
    pub saved_set_uid: u32,
    pub saved_set_gid: u32,
    pub fs_uid: u32,
    pub fs_gid: u32,
}

Fields

real_uid: u32

The user who created this process or the UID set via setuid() by the root caller.

real_gid: u32

The group who created this process or the GID set via setgid() by the root caller.

effective_uid: u32

The UID set via setuid() by the caller.

effective_gid: u32

The GID set via setgid() by the caller.

saved_set_uid: u32

The UID set via setuid() by the root caller

saved_set_gid: u32

The GID set via setgid() by the root caller

fs_uid: u32

The UID of the running executable file of this process.

fs_gid: u32

The GID of the running executable file of this process.