Module volume

Module volume 

Structs

Volume
VolumeSpeed
VolumeStat

Functions

get_mounts
Get mounting points of all block devices by reading the /proc/mounts file.
get_volumes
Get volume information by reading the /proc/diskstats file and using the statvfs function in libc.
get_volumes_with_speed
Get volume information by reading the /proc/diskstats file and using the statvfs function in libc. And measure the speed within a specific time interval.